"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const fs_1 = __importDefault(require("fs"));
const vue_1 = require("vue");
const lodash_throttle_1 = __importDefault(require("lodash.throttle"));
const readFile = (fs, filepath) => {
    try {
        return fs.readFileSync(filepath, 'utf-8');
    }
    catch { }
    return '{}';
};
const jsonSerialize = (object) => JSON.stringify(object);
const jsonDeserialize = (string) => JSON.parse(string);
function reactiveJson(filepath, { fs = fs_1.default, serialize = jsonSerialize, deserialize = jsonDeserialize, throttle, } = {}) {
    let writeFunction = () => fs.writeFileSync(filepath, serialize(object));
    if (typeof throttle === 'number') {
        writeFunction = (0, lodash_throttle_1.default)(writeFunction, throttle);
    }
    const object = (0, vue_1.reactive)(deserialize(readFile(fs, filepath)));
    (0, vue_1.watch)(() => object, writeFunction, { deep: true });
    return object;
}
module.exports = reactiveJson;
